@@ -181,6 +181,10 @@ class Instance:
                     launcher_name="picomc",
                     launcher_version=picomc.__version__,
                     classpath=classpath,
+                    version_name=v.version_name,
+                    jar_name=v.jarname,
+                    library_directory=self.libraries_root,
+                    classpath_separator=os.pathsep,
                 )
                 sjvmargs.append(res)
 
@@ -208,6 +212,8 @@ class Instance:
                 assets_root=self.assets_root,
                 assets_index_name=v.vspec.assets,
                 game_assets=v.get_virtual_asset_path(),
+                clientid="", # TODO fill these out properly
+                auth_xuid="",
             )
             smcargs.append(res)
 
