@@ -3,9 +3,12 @@ import logging
 import coloredlogs
 
 logger = logging.getLogger("picomc.cli")
+debug = False
 
 
-def initialize(debug):
+def initialize(debug_):
+    global debug
+    debug = debug_
     coloredlogs.install(
         level="DEBUG" if debug else "INFO",
         fmt="%(levelname)s %(message)s",
